==> easy-antd-modal-1.1.0.tgz: package/lib/context/index.js <==
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/context/index.tsx
var context_exports = {};
__export(context_exports, {
  EasyAntdModalContext: () => EasyAntdModalContext,
  EasyAntdModalProvider: () => EasyAntdModalProvider,
  useEasyAntdModalContext: () => useEasyAntdModalContext
});
module.exports = __toCommonJS(context_exports);
var React = __toESM(require("react"));
var EasyAntdModalContext = React.createContext({
  triggerProps: "trigger",
  contentProps: "children"
});
var useEasyAntdModalContext = () => React.useContext(EasyAntdModalContext);
var EasyAntdModalProvider = (props) => {
  const {
    triggerProps: parentTriggerProps = "trigger",
    contentProps: parentContentProps = "children"
  } = useEasyAntdModalContext();
  const { children, triggerProps = parentTriggerProps, contentProps = parentContentProps } = props;
  if (triggerProps === contentProps) {
    throw new Error(`"triggerProps" and "contentProps" cannot be the same`);
  }
  const memoizedContextValue = React.useMemo(
    () => ({
      triggerProps,
      contentProps
    }),
    [triggerProps, contentProps]
  );
  return /* @__PURE__ */ React.createElement(EasyAntdModalContext.Provider, { value: memoizedContextValue }, children);
};
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  EasyAntdModalContext,
  EasyAntdModalProvider,
  useEasyAntdModalContext
});

==> easy-antd-modal-1.4.0.tgz: package/lib/context/index.js <==
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/context/index.tsx
var context_exports = {};
__export(context_exports, {
  EasyAntdModalContext: () => EasyAntdModalContext,
  EasyAntdModalProvider: () => EasyAntdModalProvider,
  useEasyAntdModal: () => useEasyAntdModal
});
module.exports = __toCommonJS(context_exports);
var React = __toESM(require("react"));
var EasyAntdModalContext = React.createContext({
  triggerProps: "trigger",
  contentProps: "children"
});
var useEasyAntdModal = () => React.useContext(EasyAntdModalContext);
var EasyAntdModalProvider = (props) => {
  const {
    triggerProps: parentTriggerProps = "trigger",
    contentProps: parentContentProps = "children"
  } = useEasyAntdModal();
  const { children, triggerProps = parentTriggerProps, contentProps = parentContentProps } = props;
  if (triggerProps === contentProps) {
    throw new Error(`"triggerProps" and "contentProps" cannot be the same`);
  }
  const memoizedContextValue = React.useMemo(
    () => ({
      triggerProps,
      contentProps
    }),
    [triggerProps, contentProps]
  );
  return /* @__PURE__ */ React.createElement(EasyAntdModalContext.Provider, { value: memoizedContextValue }, children);
};
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  EasyAntdModalContext,
  EasyAntdModalProvider,
  useEasyAntdModal
});
